# Calculation method
The total operating costs of an aircraft are split into direct operating costs (DOC) and indirect operating costs (IOC).
$$
  TOC = DOC + IOC
$$

!!! note
    Unless explicitly stated, all values are in SI units and all costs in EUR.

## Direct operating costs
The Direct Operating Costs (DOC) are directly influenced by the parameters and the aircraft's performance and are commonly used for aircraft evaluation. Therefore, a simplified method for DOC estimation, based on „From Aircraft Performance to Aircraft Assessment“ by J. Thorbeck <sup>[1]</sup>, is provided. The DOC are determined for one year and the entire depreciation period.

Two elements are required for the simplified DOC model: The route independent (fixed) costs $C_1$ and route dependent (variable) costs $C_2$:
$$
  DOC = C_1 + C_2
$$


### Route independent costs
Route-independent costs include all cost components apart from the operation of the aircraft.
Hence, the route-independent costs are the sum of the capital costs and the crew costs:
$$
  C_1 = C_{\text{capital}} + C_{\text{crew}}
$$

Those are calculated both, for one year and for the depreciation period.

#### Capital costs
The capital costs can be assumed to be a linear function of the operating empty mass if the influence of the aircraft market is considered negligible:
$$
  C_{\text{capital}} = P_{\text{OE}} \cdot  m_{\text{OE}} \cdot (a + f_{\text{I}})
$$

In which

- $P_{\text{OE}}$ - price per kg operating empty mass
- $m_{\text{OE}}$ - operating empty mass
- $a$ - annuity factor in percent
- $f_{\text{I}}$ - insurance rate in percent

The annuity formula, which is based on a modified mortgage equation, addresses both yearly depreciation and interest:
$$
  a = f_{\text{IR}} \cdot \frac{1 - f_{\text{RV}} \cdot \left( \frac{1}{1 + f_{\text{IR}}} \right)^{t_{\text{DEP}}}}{1 - \left( \frac{1}{1 + f_{\text{IR}}} \right)^{t_{\text{DEP}}}}
$$

In which

- $f_{\text{IR}}$ - interest rate in percent
- $f_{\text{RV}}$ - residual value factor in percent
- $t_{\text{DEP}}$ - depreciation period in years

The reason for the annuity method modification is to include the residual aircraft value at the end of the depreciation period into the capital costs, which is occasionally relevant. This assumes that an operator is purchasing an aircraft at a constant price per kilogram and spends the corresponding capital cost consistently per year throughout the depreciation period.

The residual value factor depends on the depreciation period and can be determined based on the following information:

Depreciation period         | Residual value factor |
----------------------------|:---------------------:|
up to 5 years               |          0.7%         |
up to 10 years              |          0.5%         |
up to 15 years              |          0.3%         |
more than 15 years          |          0.1%         |

#### Crew costs
This method is based on the lecture "J Flugzeugbewertung" by A. Bardenhagen <sup>[2]</sup>.
The annual crew costs are assumed to be the sum of the flight and cabin crew costs:
$$
  C_{\text{crew}} = C_{\text{FC}} + C_{\text{CC}}
$$

both of which are of different levels. There are different approaches here, which must be adapted to the respective cost structure of the airline:

- Some airlines (mainly low-cost carriers) employ and pay pilots and flight attendants on a time basis (block hours).
- Other airlines hire their personnel permanently and must pay them irrespective of the time they are deployed.

In the first case, the personnel costs belong to the variable in the second case to the fixed direct operating costs. Here, crew costs are assumed to be fixed (route independent) because an airline must provide enough crews to ensure flight operations over the entire service time and therefore are proportional to the payload. 50 passengers per flight attendant are assumed based on certification requirements.

Crew costs are constant per year. To calculate the crew cost for several years, the expected salary increase should be considered by an escalation factor. Accordingly, past price levels can be extrapolated to the current level changed according to inflation, price, or salary increase.

Both cost shares are determined by the same variables:

- The flight/cabin crew complement (the number of crews per aircraft, dependent on the stage length): $n_{\text{FCC}}$/$n_{\text{CCC}}$,
- the number of flight/cabin crew members: $n_{\text{FC}}$/$n_{\text{CC}}$,
- the annual salary of a flight/cabin crew member (dependent on the stage length): $S_{\text{FC}}$/$S_{\text{CC}}$, and
- the escalation factor in percent: $f_{\text{ESC}}$.

<!-- NOTE: The values of these drivers depend on the stage length. Two modes are implemented. Mode 1 (salary_variation = False, default): To ensure that the values of the above-mentioned parameters are the same for the design mission and mission study, the stage length of the design mission is used to determine the values for the study mission as well. Mode 2 (salary_variation = True): The above-mentioned values are obtained for different stage lengths for the design mission and mission study. -->

That results in the following calculations:
$$
  C_{\text{FC}} = n_{\text{FCC}} \cdot n_{\text{FC}} \cdot S_{\text{FC}} \cdot f_{\text{ESC}}
$$

$$
  C_{\text{CC}} = n_{\text{CCC}} \cdot n_{\text{CC}} \cdot S_{\text{CC}} \cdot f_{\text{ESC}}
$$

The escalation factor
$$
  f_{\text{ESC}} = (1 + r_{\text{INF}})^{y}
$$

incorporates the inflation rate ($r_{\text{INF}}$), which encompasses both price and salary adjustments, and the number of years elapsed between the calculation year and the base year for salaries ($y$).
If the depreciation period is used as the time difference, resulting costs are related to the whole depreciation period, whereas a time difference of one year solely results in the costs for the base year.

The crew complements as well as the average annual salaries are dependent on the stage length:

- Regional: ranges less than 500 km
- Short haul: ranges between 500 km and 1000 km
- Medium haul: ranges between 1000 km and 4000 km
- Long haul: ranges between 4000 km and 6500 km
- Ultra-long haul: ranges above 6500 km

and can be taken from the following tables:

Segment         | Crew complement | $S_{\text{FC}}$ in EUR/y | $S_{\text{CC}}$ in EUR/y |
----------------|:---------------:|:------------------------:|:------------------------:|
Regional        |        5        |          70,000          |          30,000          |
Short haul      |        5        |         120,000          |          30,000          |
Medium haul     |        5        |         160,000          |          30,000          |
Long haul       |        8        |         200,000          |          45,000          |
Ultra-long haul |        8        |         200,000          |          45,000          |

### Route dependent costs
Route dependent costs $C_2$ include all cost components that are directly attributable to flight operations. These include

- fuel $C_\text{F}$,
- fees (handling $C_\text{H}$, landing $C_\text{LDG}$, air traffic control (ATC) $C_{\text{ATC}}$), and
- maintenance $C_{\text{MRO}}$.

Thus, the **annual** route dependent costs can be calculated by
$$
  C_2 = C_\text{F} + C_\text{H} + C_\text{LDG} + C_{\text{ATC}} + C_{\text{MRO}}
$$

#### Flights per year
Knowing the number of annual flights is mandatory to calculate the above-mentioned cost shares.
A reliable approximation of the number of annual flights can be found using the following analytical basis:

- Potential flight hours per year: $365 \cdot 24 = 8760$
- Maintenance lay days per year (C-Check every 15 months for 4 days): $4 \cdot 12/15 = 3.2$
- Overhaul lay days per year (D-Check every 5 years for 4 weeks): $4 \cdot 7/5 = 5.6$
- Lay days for repairs, technical and operational reserve: $2.6$
- Lay hours per year: $(3.2+5.6+2.6) \cdot 24 = 273.6$
- Potential operation days per year: $365-(3.2+5.6+2.6) = 353.6$
- Daily night curfew hours: $7$
- Yearly  night curfew hours: $354 \cdot 7 = 2475$
- Yearly operation time in hours: $OT = 8760-2475-273.6 = 6011.4$

Knowing the time for one flight $FT$ and the block time supplement $BT$ (turn around time) per flight, the number of flight cycles $FC$ can be calculated:
$$
  FC = \frac{OT}{(FT + BT)}
$$
It is assumed that one flight cycle consists of an outbound flight, a turnaround time and a return flight. Consequently, the number of annual flights is calculated as follows:
$$
  n_{\text{flights}} = 2 \cdot FC
$$

#### Fuel costs
The fuel costs depend on the fuel price $P_\text{F}$, the trip fuel mass $m_{\text{TF}}$ (which can be obtained from the payload range diagram (PRD)), and the number of yearly flights $n_{\text{flights}}$:
$$
  C_\text{F} = P_{\text{F}} \cdot m_{\text{TF}} \cdot n_{\text{flights}}
$$

#### Handling costs
Handling charges $F_\text{H}$ include charges for loading and unloading, use of terminals and passenger boarding bridges, security checks, and ground energy supply.
The annual handling fees are charged based on the payload mass $m_{\text{PL}}$ and the number of flights per year. The resulting handling costs are calculated as follows:
$$
  C_\text{H} = m_{\text{PL}} \cdot F_{\text{H}} \cdot n_{\text{flights}}
$$

#### Landing costs
The annual landing fees $F_{\text{LDG}}$ are charged based on the maximum (certified) takeoff mass $m_{\text{TO}}$ and number of flights per year. The resulting landing costs are calculated as follows:
$$
  C_{\text{LDG}} = m_{\text{TO}} \cdot F_\text{L} \cdot n_{\text{flights}}
$$

#### Air traffic control costs
The calculation of the ATC costs is based on the EUROCONTROL route charge formula <sup>[3]</sup>, more precisely the aircraft weight factor.

> "The weight factor (expressed to two decimals) is determined by dividing, by fifty (50), the certificated Maximum Take-Off Weight (MTOW) of the aircraft (in metric tonnes, to one decimal) and subsequently taking the square root of the result rounded to the second decimal [...]".

The ATC price factor $f_{\text{ATC}}$ considers the fact that the price scenarios are varying strongly for each continent (or even region):

- $f_{\text{ATC}} = 1.0$ for domestic europe
- $f_{\text{ATC}} = 0.7$ for transatlantic flights
- $f_{\text{ATC}} = 0.6$ for far east flights (only half of the landings at european airports)

The ATC costs are calculated as follows:
$$
  C_{\text{ATC}} = R \cdot f_{\text{ATC}} \cdot \sqrt{\frac{m_{\text{TO}}[\text t]}{50}} \cdot n_{\text{flights}}
$$

with

- $R$ - range in km
- $m_{\text{TO}}$ - maximum takeoff mass (in tonnes)

#### Maintenance costs
Maintenance costs are categorized into three components:

- Flight cycle dependent cost: This component primarily accounts for structural fatigue and overhaul burdens.
- Flight hour dependent cost: This component primarily reflects wear and the associated line maintenance work.
- Calendar time dependent cost: This component represents a constant share, such as the rectification of corrosion during overhaul.

In the following, only the maintenance costs per flight cycle are considered. Following the JADC method, an approximation for those costs is given by the sum of three parts:

- Airframe material maintenance cost (repair and replacement): $C_{\text{MRO,AF,MAT}}$
- Airframe personnel maintenance cost (inspection and repair): $C_{\text{MRO,AF,PER}}$
- Engine total maintenance cost: $C_{\text{MRO,ENG}}$

In which
$$
  C_{\text{MRO,AF,MAT}} = m_{\text{OE}}[\text t] \cdot (0.2 \cdot t_{\text{flight}} + 13.7) + C_{\text{MRO,AF,REP}}
$$

$$
  C_{\text{MRO,AF,PER}} = f_{\text{LR}} \cdot (1+C_\text{B}) \cdot \left[ (0.655 + 0.01 \cdot m_{\text{OE}}[\text t]) \cdot t_{\text{flight}} + 0.254 + 0.01 \cdot m_{\text{OE}}[\text t] \right]
$$

$$
  C_{\text{MRO,ENG}} = n_{\text{ENG}} \cdot \left( 1.5 \cdot \frac{T_{0} [\text t]}{n_{\text{ENG}}} + 30.5 \cdot t_{\text{flight}} + 10.6 \cdot f_{\text{MRO,ENG}}\right)
$$

with

- $C_{\text{MRO,AF,REP}}$ - airframe repair cost per flight
- $f_{\text{LR}}$ - labor rate in EUR/h
- $C_\text{B}$ - cost burden
- $n_{\text{ENG}}$ - number of engines
- $T_{0}$ - sea level static thrust per engine
- $f_{\text{MRO,ENG}}$ - engine maintenance factor

The airframe repair cost per flight $C_{\text{MRO,AF,REP}}$ equal `57.5` for kerosene-powered aircraft. For hydrogen-powered aircraft, this value is multiplied by the operating empty mass factor $f_{\text{OEM}} = 1.1$ to account for an approx. 10% higher operating empty mass.
The engine maintenance factor is considered $f_{\text{ENG}} = 1$ for kerosene-powered aircraft and $f_{\text{ENG}} = 0.7$ for hydrogen-powered aircraft.

Thus, the annual maintenance costs result in
$$
  C_{\text{MRO}} = (C_{\text{MRO,AF,MAT}} + C_{\text{MRO,AF,PER}} + C_{\text{MRO,ENG}}) \cdot n_{\text{flights}}
$$

## Related direct operating costs
Absolute DOC are generally unsuitable as an assessment measure because aircraft size and technology strongly influence this figure. They are therefore expressed in differently related quantities, depending on the purpose of the evaluation:

  - DOC/Range (Flight Kilometer): Flight Kilometer Costs (FKC)
  - DOC/Seat Kilometer Offered (SKO): Seat Kilometer Costs (SKC)
  - DOC/Seat Kilometer Offered Corrected: Corrected SKC to take account of any freight revenue
  - DOC/Ton Kilometers Offered (TKO): Ton Kilometer Costs (TKC)
  - DOC/Revenue Passenger Kilometer (RPK): Revenue Seat Kilometer Costs (RSKC)

These are described below.

### Flight kilometer costs
The flight kilometer costs are very flexible and suitable for an extended consideration of changed route structures. This parameter allows the range potential of the aircraft to be assessed:
$$
  FKC = \frac{DOC}{R}.
$$

### Seat kilometer costs
The seat kilometer offered (SKO) (or available) is a measure of an aircraft's passenger carrying capacity or, in other words, its potential to generate revenue by providing available seats to passengers. They are calculated by multiplying the number of seats available $n_{\text{seats}}$ by the range:
$$
  SKO = n_{\text{seats}} \cdot R.
$$

The seat kilometer costs allow the analysis of a change in seat capacity and thus the assessment of the passenger kilometer potential:
$$
  SKC = \frac{DOC}{SKO}
$$

### Corrected seat kilometer costs

!!! note 
    The calculation of this cost share is not implemented at the moment and set to `0` instead.

A method of freight equivalent passenger seats is applied.
Cargo revenue from residual cargo payload at maximum zero fuel mass ($m_{\text{PL,max}} - m_{\text{PL}}$) can be calculated using
$$
  I_{\text{cargo}} = I_{\text{FR}} \cdot (W_{\text{PL,max}} - W_{\text{PAX}})
$$

with

- $I_{\text{FR}}$ - revenue per freight kilometer
- $W_{\text{PL,max}}$ - maximum payload weight
- $W_{\text{PAX}}$ - pax weight

The equivalent seat revenue can be derived using the following formula:
$$
  n_{\text{PAX,cargo}} = \frac{I_{\text{cargo}}}{I_{\text{PAX}}}
$$

with $I_{\text{PAX}}$ as revenue per seat and flight (see following table).

Segment         | $I_{\text{PAX,multi-class}}$ in EUR/SO | $I_{\text{PAX,all-economy}}$ in EUR/SO |
----------------|:--------------------------------------:|:--------------------------------------:|
Short haul      |                  400                   |                  250                   |
Medium haul     |                  450                   |                  300                   |
Long haul       |                  550                   |                  400                   |
Ultra long haul |                  700                   |                  550                   |

Finally, the SKC correction can be determined as follows:
$$
  SKC_{\text{cor}} = SKC \cdot \frac{n_{\text{PAX}}}{n_{\text{PAX}} + n_{\text{PAX,cargo}}}
$$

### Ton kilometer costs
The ton kilometer costs (TKC) allow the analysis of a change in payload capacity and thus the assessment of the payload kilometer potential. The Ton Kilometers Offered (TKO) are the product of the payload and the range:
$$
  TKO = m_{\text{PL}} \cdot R
$$

The Ton Kilometer Costs (TKC) are the DOC related to the TKO:
$$
  TKC = \frac{DOC}{TKO}
$$

### Revenue seat kilometer costs
Revenue passenger kilometers (RPK) are a measure of how many kilometers the aircraft has carried paying passengers. It is often referred to as "traffic" as it represents the actual demand for air transport. The RPK are determined by multiplying the range by the number of paying passengers. The revenue passenger kilometers are calculated by multiplying the number of revenue passengers with the maximum number of seats and the seat load factor $f_{\text{SL}}$:
$$
  RPK = n_{\text{PAX}} \cdot f_{\text{SL}} \cdot R
$$

The DOC per revenue passenger kilometer additionally take into account the overall performance of an airline. Note that revenue is strongly dependent on market situation and therefore varying.
$$
  RSKC = \frac{DOC}{RPK}
$$

## Indirect operating costs (IOC)
tbd. :construction:

---
<sup>[1]</sup> J. Thorbeck, 2007. *From Aircraft Performance to Aircraft Assessment*. DLR.<br>
<sup>[2]</sup> A. Bardenhagen, 2017. *J Flugzeugbewertung*. Technische Universität Berlin.<br>
<sup>[3]</sup> EUROCONTROL Central Route Charge Office (CRCO), 2022. *Customer Guide to Charges*. URL: https://www.eurocontrol.int/sites/default/files/2022-11/eurocontrol-customer-guide-to-charges.pdf.