# climate_model_dallara {#climate-model-dallara}
The climate model, referred to here as the "Dallara" model, calculates key climate impact metrics: Radiative Forcing (RF), Absolute Global Warming Potential (AGWP), Absolute Global Temperature Potential (AGTP), and Average Temperature Response (ATR). The calculation methodology is derived from Dallara's work in 2011 \cite Dal11, providing a systematic approach to assess the environmental effects of various emissions.

Key Metrics:
- **RF**: quantifies the change in energy flux in the Earth's atmosphere due to emissions, specifically related to greenhouse gases, aerosols, and other components like soot or water vapor.
- **AGWP**: measures the cumulative impact of an emission over a specific time horizon (typically 20, 100, or 500 years), comparing it to CO₂'s effect.
- **AGTP**: calculates the temperature change due to emissions at a given point in time, typically looking at how gases contribute to warming.
- **ATR**: ATR evaluates the mean temperature change over time.


## General principles {#climate-model-generalprinciples}
The model assesses the climate impact of following emissions:
- CO₂ (Carbon dioxide)
- H₂O (Water vapor)
- Soot (Black carbon)
- Ozone (O₃) (both long-lived and short-lived forms) and CH₄ (Methane), which are influenced by NOₓ emissions

A particular feature of the method is the usage of forcing factors, which are unitless parameters. These factors modify the radiative forcing for emissions at different altitudes by normalizing the RF values to a fleetwide average. The altitude is the only flight trajectory parameter considered, meaning the geographic location is not factored into the calculations. This altitude dependency recognizes that emissions at higher altitudes (such as those from aviation) have a different forcing impact compared to emissions at ground level, as atmospheric processes and the distribution of pollutants vary with height.

In the model, you can explore how the influence of time affects climate impact by adjusting the rate of devaluation for temperature response. A value of zero indicates that the temperature changes occurring after operations are given equal weight compared to changes during the operational period. Higher values of the rate, however, signify that postoperation impacts become progressively less important over time, with each subsequent year's temperature change being less significant than that of the previous year.

## Input-Data {#climate-model-input}
From the acxml following parameter are needed:
```xml
<aircraft_exchange_file>
    <requirements_and_specifications>
        <design_specification>
            <assessment_scenario>
                <flights_per_year>
                    <unit>1</unit>
                    <value>2227</value>
                    <lower_boundary>0</lower_boundary>
                    <upper_boundary>4000</upper_boundary>
                </flights_per_year>
            </assessment_scenario>
        </design_specification>
    </requirements_and_specifications>
    <anlysis>
        <study_mission>
            <range>
                <unit>m</unit>
                <value>927191.902</value>
                <lower_boundary>0</lower_boundary>
                <upper_boundary>5000000</upper_boundary>
            </range>
            <top_of_climb_range>
                <unit>m</unit>
                <value>140079.6691</value>
                <lower_boundary>0</lower_boundary>
                <upper_boundary>5000000</upper_boundary>
            </top_of_climb_range>
            <top_of_descent_range>
                <unit>m</unit>
                <value>741036.0403</value>
                <lower_boundary>0</lower_boundary>
                <upper_boundary>5000000</upper_boundary>
            </top_of_descent_range>
            <cruise_steps>
                <cruise_step ID="0">
                    <relative_end_of_cruise_step>
                        <unit>1</unit>
                        <value>1</value>
                        <lower_boundary>0</lower_boundary>
                        <upper_boundary>1</upper_boundary>
                    </relative_end_of_cruise_step>
                    <altitude>
                        <unit>m</unit>
                        <value>10668</value>
                        <lower_boundary>0</lower_boundary>
                        <upper_boundary>15000</upper_boundary>
                    </altitude>
                </cruise_step>
            </cruise_steps>
        </study_mission>
    </anlysis>
</aircraft_exchange_file>
```
The Submodel reads following data from the path `module_configuration_file/program_settings/standard_strategy/impact_calculation`in the configuration file:
```xml
<climate_model_methods>
    <method>
        <value>DALLARA</value>
    </method>
    <dallara>
        <fuel_factor_AIC>
            <unit>1</unit>
            <value>0.6</value>
            <lower_boundary>0.3</lower_boundary>
            <upper_boundary>1</upper_boundary>
        </fuel_factor_AIC>
        <max_integration_period>
            <unit>a</unit>
            <value>200</value>
            <lower_boundary>0</lower_boundary>
            <upper_boundary>1000</upper_boundary>
        </max_integration_period>
        <devaluation_rate>
            <unit>1</unit>
            <value>0.03</value>
            <lower_boundary>0</lower_boundary>
            <upper_boundary>10^10</upper_boundary>
        </devaluation_rate>
        <forcing_factors>
            <variations>
                <aircraft_induced_cloudiness>
                    <unit>1</unit>
                    <value>1</value>
                    <lower_boundary>0.67</lower_boundary>
                    <upper_boundary>1.33</upper_boundary>
                </aircraft_induced_cloudiness>
                <short_lived_ozone>
                    <unit>1</unit>
                    <value>1</value>
                    <lower_boundary>0.67</lower_boundary>
                    <upper_boundary>1.33</upper_boundary>
                </short_lived_ozone>
                <methan_and_long_lived_ozone>
                    <unit>1</unit>
                    <value>1</value>
                    <lower_boundary>0.67</lower_boundary>
                    <upper_boundary>1.33</upper_boundary>
                </methan_and_long_lived_ozone>
            </variations>
            <data_set_selector>
                <value>mode_0</value>
            </data_set_selector>
        </forcing_factors>
    </dallara>
</climate_model_methods>
```

Additionally, the emission masses of the study missions are needed:
```xml
<calculation_results description="Results of calculation method">
        <mission_emissions description="Results of mission emission calculation">
            <study_mission description="Results of study mission calculation">
                <emissions description="Emissions of study mission">
                    <LTO_cycle description="Emissions of landing and takeoff cycle">
                        <CO2 description="LTO CO2 emissions of one study mission">
                            <value>0</value>
                            <unit>kg</unit>
                            <lower_boundary>-1.797693135e+308</lower_boundary>
                            <upper_boundary>1.797693135e+308</upper_boundary>
                        </CO2>
                        <H2O description="LTO H2O emissions of one study mission">
                            <value>0</value>
                            <unit>kg</unit>
                            <lower_boundary>-1.797693135e+308</lower_boundary>
                            <upper_boundary>1.797693135e+308</upper_boundary>
                        </H2O>
                        <SO4 description="LTO SO4 emissions of one study mission">
                            <value>0</value>
                            <unit>kg</unit>
                            <lower_boundary>-1.797693135e+308</lower_boundary>
                            <upper_boundary>1.797693135e+308</upper_boundary>
                        </SO4>
                        <NOx description="LTO NOx emissions of one study mission">
                            <value>0</value>
                            <unit>kg</unit>
                            <lower_boundary>-1.797693135e+308</lower_boundary>
                            <upper_boundary>1.797693135e+308</upper_boundary>
                        </NOx>
                        <soot description="LTO Soot emissions of one study mission">
                            <value>0</value>
                            <unit>kg</unit>
                            <lower_boundary>-1.797693135e+308</lower_boundary>
                            <upper_boundary>1.797693135e+308</upper_boundary>
                        </soot>
                    </LTO_cycle>
                    <cruise description="Emissions of cruise phase">
                        <CO2 description="Cruise CO2 emissions of one study mission">
                            <value>0</value>
                            <unit>kg</unit>
                            <lower_boundary>-1.797693135e+308</lower_boundary>
                            <upper_boundary>1.797693135e+308</upper_boundary>
                        </CO2>
                        <H2O description="Cruise H2O emissions of one study mission">
                            <value>0</value>
                            <unit>kg</unit>
                            <lower_boundary>-1.797693135e+308</lower_boundary>
                            <upper_boundary>1.797693135e+308</upper_boundary>
                        </H2O>
                        <SO4 description="Cruise SO4 emissions of one study mission">
                            <value>0</value>
                            <unit>kg</unit>
                            <lower_boundary>-1.797693135e+308</lower_boundary>
                            <upper_boundary>1.797693135e+308</upper_boundary>
                        </SO4>
                        <NOx description="Cruise NOx emissions of one study mission">
                            <value>0</value>
                            <unit>kg</unit>
                            <lower_boundary>-1.797693135e+308</lower_boundary>
                            <upper_boundary>1.797693135e+308</upper_boundary>
                        </NOx>
                        <soot description="Cruise Soot emissions of one study mission">
                            <value>0</value>
                            <unit>kg</unit>
                            <lower_boundary>-1.797693135e+308</lower_boundary>
                            <upper_boundary>1.797693135e+308</upper_boundary>
                        </soot>
                    </cruise>
                </emissions>
            </study_mission>
    </mission_emissions>
</calculation_results>
```


## Output-Data {#climate-model-output}
The results are saved within the following files:
- acXML parameter: `/aircraft_exchange_file/assessment/ecological_assessment/average_temperature_response`
- html report: `aircraft_exchange_file_directory/reporting/reportHTML/ecological_assessment_report.html`
- tex report: `aircraft_exchange_file_directory/reporting/reportTeX/ecological_assessment_report.tex`
- csv file: `aircraft_exchange_file_directory/reporting/plots/csv_files/ecological_assessment_climateImpact.csv`