# Basic Concepts {#basic-concepts}
This chapter introduces the definitions and theoretical concepts used in UNICADO for performing the weight and balance (w&b) analysis. The masses of the aircraft's components are calculated in the corresponding design modules. Each component has a _mass properties_ information containing the component's mass, center of gravity position and moments of inertia. All mass properties are gathered in this module and summed up to the different total aircraft's masses, CG positions and mass moments of inertia. Given the airplane design with its requirements and the mass breakdown of its components, the weight and balance of the aircraft is computed considering the mission data and transport task information from the _Aircraft Exchange File_ (acxml). Finally, the loading diagramm is plotted to show different loading cases and the CG-shift during flight. 

 For some calculations there are more available methods. These can be selected by the user in the w&b tool configuration file [_weight\_and\_balance\_analysis\_conf.xml_](usage.md). 

> [!NOTE] 
> In this beta release of UNICADO the w&b analysis module is laid out for the _tube and wing_ configuration of a look-a-like A320. This will be extended in the future to support also a blended wing body configuration.


## Masses of the Aircraft {#masses}
 
Let us start defining the different masses calculated by the tool and how they are determined: 

- The **Manufacture Empty Mass (MEM)** is the mass of the aircraft which includes the mass of the main components, i.e. the airframe structure (wing, fuselage, landing gear, empennage, pylons), the propulsion group (nacelles and engines) mass and the fixed equipment mass like the furnishings or the navigation systems.
  
> [!NOTE] 
> The tanks don't have an own mass as they are integrated in the main components. Only for the case of additional tanks a mass is added.  

- The **Operating Empty Mass (OEM)** represents the mass of the aircraft which includes the crew, all essential operational fluids and all operator-required items and equipment for flight. It coresponds to the MEM with addition of the operator items mass. 

  $ OEM = MEM + operator\_items\_mass $ 

> [!NOTE]
> The operator items are calculated by both the fueselage design and the systems design module.

- The **Maximum Zero Fuel Mass (MZFM)** is the total mass of the aircraft without any fuel. It is calculated with 
  
  $MZFM = OEM + maximum\_payload\_mass $

  - The ***maximum payload mass*** is refering to the maximum allowed payload which can be taken on board without violation of the structural limits and capacity constraints. This is defined in the TLARs.

- The **Ferry Range Mass (FRM)** is the mass at which the aircraft can reach the maximum range. For this, no payload is carried and the tanks are filled up with the maximum fuel mass. 
  
  $ FRM = OEM + maximum\_fuel\_mass $

  - The ***maximum fuel mass*** is the maximum fuel that can be carried and fits in all tanks up to the maximum capacity, i.e all tanks are full. The tank design module outputs the maximum energy per each designed tank. These are transformed here with the corresponding gravimetric density to a maximum fuel mass per tank and then summed up for all tanks.  

- The **Maximum Take-Off Mass (MTOM)** is the mass at which the aircraft takes off. For the design mission this corresponds to the design mass at take-off. Starting with the previously determined OEM, the calculated design fuel at takeoff and the design payload mass are added:
  
  $ MTOM = OEM + design\_fuel\_mass\_takeoff + design\_payload\_mass $

> [!NOTE]
> The estimated MTOM is an input of the weight and balance analysis tool and is initially written by the _initial\_sizing_ module. Here, it is updated to a mass based on more exact calculation, as the components design and its mass breakdown is now known.

  - The ***design payload mass*** consists of the passenger, luggage and additional cargo mass defined by the user in the transport task. 
  - The ***design fuel mass mission*** is the fuel mass determined from the mission information and is equal to the mission energy (including taxi and reserves) divided by the gravimetric density of the energy provider. If the energy needed to complete the mission is not available or unknown, the design fuel mass is calculated from the difference between the estimated MTOM, OEM and the design payload mass.
  - The ***design fuel mass takeoff*** corresponds to the remaining fuel in the tanks after the taxi at the origin, just before the take-off. The design fuel mass at takeoff is equal to the ***design fuel mass*** written in the acxml. 
  - The ***design fuel mass midflight*** is calculated by substracting from the design fuel mass at takeoff the fuel consumed during the take-off segment and half of the fuel needed for the cruise segment. These data are provided by the mission module. If not, the design fuel mass midflight is approximated to be half of the design fuel mass at takeoff. 
  - The ***design fuel mass landing*** corresponds to the remaining fuel in the tanks just after the plane touched down. The minimum fuel mass at landing is determined by substracting from the mission fuel mass the trip fuel mass (containing all flight segments) and the taxi fuel mass before the take-off. If no mission information is available, the minimum design fuel mass at landing is calculated by multiplying the design fuel mass at takeoff with factors for the contingency fuel, alternate fuel and the final fuel reserve. 

  With the knowledge about the OEM, the design payload mass and the design fuel masses at different points during flight, the total design masses of the aircraft at specific times can be calculated: 
  - ***design mass mission*** (the mass of the aircraft in the parking position before the start) $design\_mass\_mission = OEM + design\_fuel\_mass\_mission + design\_payload\_mass. $
  - ***design mass at take-off*** (equal with the MTOM and to the ***design mass*** written in the acxml)
  - ***design mass at midflight*** 
  - ***design mass at landing***

- The **Maximum Landing Mass (MLM)** is the maximum mass at which the pilot of the aircraft is allowed to attempt to land due to structural or other limits. 
Two calculation modes are available:
  - based on the mission information and the consumed fuel during flight (`default method`):
    $MLM = OEM + design\_fuel\_mass\_landing + design\_payload\_mass $
  - via the `RWTH regression method`: This calculation uses different formulas depending on whether the maximum takeoff mass exceeds a threshold value of 15,000 kg.
    1. For Aircraft with *MTOM > 15,000 kg* the following empirical formula is used:  
     $MLM = 1.9689 \times MTOM^{0.9248}$
    2. For Aircraft with *MTOM ≤ 15,000 kg* a linear approximation is used:  
     $MLM = 0.9009 \times MTOM + 410.85 $

Additionally, two masses are calculated for the case that the aircraft flies either with maximum payload mass or with maximum fuel mass. In both cases the difference up to MTOM is completed with fuel or payload respectively. Based on the loading diagramm, the masses at the most forward and most aft CG positions are also determined. 

---
## Center of Gravity {#cg}

The knowledge of the center of gravity (CG) position and movement is necessary to ensure the static stability and controllability of the aircraft on the ground and in the air. Based on the results of the detailed mass breakdown of the components with their _mass properties_ information, the total center of gravity of the aircraft can now be determined. The position of the overall CG can generally be determined from the position of the individual centers of gravity w.r.t. a global reference point. 

The calculation involves determining the weighted average of the CG positions for all components. For each axis (_x, y ,z_), the function sums the scaled masses, which are the product of a component’s mass and its CG coordinate for the respective axis. This sum is then divided by the total mass of all components to yield the final CG coordinate for that axis. The global center of gravity ($ \text{CG} $) for a specific axis ($ \text{ax} $) is calculated as:

$
\text{CG}_{\text{ax}} = \frac{\sum_{i=1}^n (m_i \cdot x_i)}{\sum_{i=1}^n m_i}
$

Where:
- $ m_i $ is the mass of the $ i $-th component.
- $ x_i $ is the coordinate of the $ i $-th component along the $ \text{ax} $.
- $ n $ is the total number of components.

> [!NOTE] 
> It is often common to specify the center of gravity as %MAC. 

### Center of Gravity Shift and the Loading Diagramm

The various operational centre of gravity positions must always be within a range limited by safe operation. Since different loading and mission conditions can occur, proof of admissibility must be provided independently for each one. Possible extreme variants can be found in the following matrix:

| **Loading case**                | Mass | Fuel | Payload |
|---------------------------------|-----------|-----------|-----------|
| Design mission                  | MTOM      | design      | design      |
| Ferry range mission             | FRM       | maximum      | 0      |
|                                 | MZFM      | 0           | maximum      |
|                                 | MTOM      | rest        | maximum      |
|                                 | MTOM      | maximum     | rest         |

The loadind diagramm is used to display the permissible range of aircraft mass and CG positions, accounting for CG migration during loading and unloading. The shift in the CG is crucial for evaluating different loading cases from which potential loading restrictions can be determined. 

Below is a detailed breakdown of idealized key loading processes and their effects on the CG used to construct the loading diagramm. Given the vast number of possible loading combinations and scenarios, a pre-selection of critical cases—often configuration-dependent— has been made to reduce complexity. The following loading scenarios are considered within UNICADO:

**1. Passenger Boarding**
  - Critical Scenario: Boarding passengers in a _front-to-rear_ or _rear-to-front_ sequence. These sequences represent extreme cases and can significantly affect the CG position.
  - Realistic Scenario: Passengers boarding with free seat selection, typically filling _window seats first, followed by middle and aisle seats_. This simulates common boarding patterns and provides a practical estimation of CG shifts.

**2. Loading of Baggage and Cargo**
- For aircraft with similarly sized forward and aft cargo holds, the CG can be deliberately influenced by distributing containers or pallets to achieve a CG favorable for cruise flight. For rear-engine aircraft, the larger cargo hold is typically located forward of the wings. The loading scenario for cargo assumes a symmetric _front-to-rear_ or _rear-to-front_ loading sequence.

**3. Refueling**
  - Low-/Mid-Wing Aircraft: Fuel is loaded in the following order: inner tank → outer tank → central or fuselage tanks.
  - High-Wing Aircraft: Fuel is loaded in reverse: outer tank → inner tank → central or fuselage tanks.
  
> [!NOTE] 
> It is assumed that the tanks are filled up symmetrically in the mentioned order up to the maximum capacity of each tank with the fuel mass calculated based on the mission information. 

**4. Defueling (Fuel Consumption During Flight)**
  - Low-/Mid-Wing Aircraft:
    - Fuel is consumed in the order: central or fuselage tanks → inner tank → outer tank.
  - High-Wing Aircraft:
    - Fuel is consumed in the reverse order: central or fuselage tanks → inner tank → outer tank.

> [!NOTE] 
> For the moment only the loading case 3 - 1 - 2 - 4 is implemented. The different selection of the loading scenarios can be made in the _weight\_and\_balance\_analysis\_conf.xml_ file.

Finally, the **most forward and most aft _x_-CG positions** and the corresponding masses are depicted from the resulting diagramm.  

---
## Mass Moments of Inertia {#inertia}

Inertia forces arise from the tendency of mass to resist accelerations. For rotational accelerations, these forces are represented by the **mass moment of inertia** terms.These are critical parameters in the analysis and design of aircraft, as they determine the rotational dynamics about the principal axes: roll, pitch, and yaw. These values influence stability, control responsiveness, and handling qualities. The moments of inertia are calculated relative to an axis and depend on the mass distribution of the aircraft. The cross products of inertia (e.g., $ I_{xy} $) arise when the axes are not aligned with the principal axes of the mass distribution.

In this context the mass moments of inertia about the three principal axes 
- $ I_{xx} $: About the roll axis  
- $ I_{yy} $: About the pitch axis  
- $ I_{zz} $: About the yaw axis
> [!NOTE]
> The mass moments of inertia are calculated only for the total masses.  
  
are determined determined by means of the following ***calculation methods:***

#### 1. Using Raymer's Empirical Equations 
*Raymer* provides empirical formulas to estimate the moments of inertia based on the aircraft's geometry and mass distribution. These equations are derived from historical data based on nondimensional radii of gyration ($ R_x $, $ R_y $, $ R_z $) and are suitable for early design phases where detailed component-level data may not be available. The mass moments of inertia are given as follows:

- **Roll**: $I_{xx} = \frac{b^2 M R_x^2}{4} \cdot f_{xx}$
- **Pitch**: $I_{yy} = \frac{l^2 M R_y^2}{4} \cdot f_{yy} $
- **Yaw:** $I_{zz} = \frac{\left( \frac{b + l}{2} \right)^2 M R_z^2}{4}$

Where:  
- $ b $: Wingspan  
- $ l $: Fuselage length  
- $ M $: Aircraft mass
- $f_{xx}$ and $f_{yy}$: Technology factors set to $1.25$ respectively $1.15$   
- $ R_x, R_y, R_z $: Nondimensional radii of gyration. The following values are implemented:

| **Aircraft Configuration**                      | $ R_x $ | $ R_y $ | $ R_z $ |
|-----------------------------------------|-----------|-----------|-----------|
| Fuselage-mounted engines                | 0.24      | 0.34      | 0.42      |
| 2 wing-mounted engines                  | 0.23      | 0.33      | 0.45      |
| 4 wing-mounted engines                  | 0.24      | 0.36      | 0.44      |
| Blended wing body                       | 0.28      | 0.40      | 0.46      |


#### 2. Using the LTH Tables (*Luftfahrttechnisches Handbuch*) 
The LTH provides tabulated values and empirical methods specific to various aircraft configurations. These tables account for typical mass distributions and structural layouts. They are more accurate than Raymer’s approach but require knowledge of the specific aircraft class and design. The `calculate_inertia_by_lth_method` function is tailored specifically for conventional tube-and-wing configurations. This method uses aircraft mass properties like the OEM, the payload mass ($m_{payload}$) and the fuel mass ($m_{fuel}$) and geometric dimensions such as wing span $b$ and fuselage length $l$. All cross-product terms ($I_{xy}$, $I_{xz}$, etc.) are set to $0$, assuming symmetry.

The mass moments of inertia around the principal axes are given as follows:

- **Roll**:
  $
  I_{xx} = f_{xx} \cdot K_x^2 \cdot b^2 \cdot m_m
  $

- **Pitch**:
  $
  I_{yy} = f_{yy} \cdot K_y^2 \cdot l^2 \cdot m_m
  $

- **Yaw**:
  $
  I_{zz} = 0.96 \cdot (I_{xx} + I_{yy})
  $

Here, $f_{xx}$ and $f_{yy}$ are technology factors set to $0.8$ respectively $0.9$. The expected mass $M$ and the scaling factors $K_x$ and $K_y$, derived from empirical LTH tables, are defined as:

  $ M = OME + m_{payload} + m_{fuel} $

  $ K_x = \frac{1}{12} \left( \left[ - \frac{2}{3} \cdot \left(\frac{M}{OME}- 1\right) + \frac{m_{fuel}}{OME} \right] +1 \right) + 0.065 $

  $ K_y = -\frac{0.065}{1.72} \left[ 0.2 \cdot \left(\frac{M}{OME}- 1\right) + \frac{m_{fuel}}{OME} \right] + 0.2025 $


#### 3. Using the Component's Inertia
This method involves calculating the total inertia tensor of the aircraft based on its components' individual mass properties. For each inertia component ($I_{xx}$, $I_{xy}$, etc.), the function adds the component's intrinsic inertia and the inertia due to its offset from the reference CG (using the Steiner theorem). The mass moments of inertia are given exemplary    

- around the principal axes ($I_{xx}$, $I_{yy}$,$I_{zz}$): 
$
I_{xx} = \sum (I_{xx},{\text{component}} + m_{\text{component}} \cdot (p^2 + q^2))
$  
- around the deviation axes (cross-product terms $I_{xy}$, $I_{xz}$, etc.): 
$
I_{xy} = \sum (I_{xy},{\text{component}} + m_{\text{component}} \cdot -(p \cdot q))
$  


with $p$ and $q$ representing the relative distances between the reference center of gravity (CG) and the current component's CG along the specified axes. Specifically:
- $ p $: The distance along the first axis (e.g., x, y, or z).
- $ q $: The distance along the second axis (e.g., x, y, or z). 
 
> [!NOTE]
> The component's moments of inertia, if available, are calculated in the component's design modules. Otherwise, these are 0.

