# Implemented Aircraft Sizing Methods and Models

## Initial Takeoff Mass Estimation MTOM 
The MTOM is initially iterated from Top Level Aircraft Requirements (TLARs), user assumptions and certification requirements.

**Methods**

The *Payload* is like its name the mass that pays for a trip. It is calculated from the number of passengers (PAX) and additional cargo requirement.
It is a fixed value for the whole iteration. 
For the determination the following parameters from the acXML are necessary:

* Number of PAX [-]
* Mass per person  [kg]
* Luggage per PAX [kg]
* Additional cargo mass [kg]


The *Crew mass* is not part of the payload but once determined it is also a fixed value for the iteration of the MTOM. 
The crew mass is dependent on the different seating classes (FC, BC, EC) and number of PAX in each class the aircraft shall have.
Furthermore, the certification requirements define the number of pilots.  
For the determination the following parameters are necessary:

acXML:
* Number of PAX in each class [-]
* Mass per person [kg] and luggage per crew are the same than for the passengers
initialSizing_conf:
* Number of pilots [-]
in source code
* Ratio for flight attendants per PAX amount in each class [-]: i.e. 1 Flight Attendant per 14 PAX in FC, 1 per 40 in EC


The *fuel* which is needed for individual mission segments is not calculated in absolute values but as mass fractions from the total remeining fuel. The fuel fractions of the cruise segment, the reserve needed to the flight to an alternate distance and the reserve for a holding time are calculated with the Breguet equation. 
For the determination the following parameters are necessary:

acXML:
* Design range [m]
* Crusie flight speed [m/s]: automatically calculated from the design machNumber
* Contingency [-]: percentage for the reserve of the trip fuel (the fuel necessary for the design range without reserves)
* Cruise flight altitutde [m]: to calculate the air density
initialSizing_conf:
* SFC of the engine with regard to fuel type [-]: 
* Glide Ratio (L/D) in cruise [-]: Initial assumption given by user
* Glide Ratio (L/D) in Loiter [-]: Initial assumption given by user


The fuel fractions (i.e. engine warm up, taxi, takeoff, climb....) are set as an static input by the user in the initialSizing_conf file.
Together with the fuel fractions from the segments calculated with the breguet equation, the overall fuel fraction of the aircraft is calculated.  
In this way of calculating the necessary fuel, the method and also the same static fuel fractions are applicable for various aircraft sizes.  


The *MTOM* is calculated in an iteration because the absolute amount of fuel and the *Operating Mass Empty* (OME) changes with the aircraft MTOM. 
The initial value for MTOM in order to start the MTOM iteration is estimated with a simple formula depending on the payload and a static factor only.
For the *OME* a mass ratio me/m0 is used in order to take into account the total aircraft size. Larger aircraft usually have a smaller empty mass / takeoff mass ratio.
In each iteration a new me/m0 ratio is calculated. Together with the fuel mass fraction, the payload and the crew mass the MTOM is determined. This iteration goes on until the convergence criteria is reached.  


## Initial Constraint Analysis - Sizing Chart  
A constraint analysis is conducted in order to set the initial *Design Point* for the aircraft. The Desing Point is defined as a wing loading and thrust to weight ratio. 
The constraint analysis is a method to make sure Top Level Aircraft Requirements (TLARs) and certification requirements will be fulfilled by the designed aircraft. 
For this a sizing chart is determined and printed by the module.

**Methods**

The *Takeoff* constraint makes sure to respect the takeoff field lengt TLAR.
For the determination the following parameters are necessary:

acXML:
* Takeoff field lenght (TOFL) [m]
initialSizing_conf:
* Number of engines [-]: is used to set a engine proportional factor
* CL_max_takeoff  [-]


The *Climb* constraint makes sure to respect the climb ability in the 2nd segment with one engine inoperative (OEI) by the certification standards.
For the determination the following parameters are necessary:

acXML:
* Minimum climb angle [rad]: according to the certification standards and the total number of engines

* L/D_climb [-]: with the highlift system in the state of the 2nd climb segment
in source code:
* Mass ratio m_climb/MTOM [-] 


The *Cruise Flight* constraint makes sure to respect the desing cruise speed and altitude TLAR.
For the determination the following parameters are necessary:

initialSizing_conf:
* Cfeq [-]: Equivalent friction coefficient to estimate parasetic drag coefficient
* Oswald efficency factor e [-]
* Wing Aspect Ratio [-]
in source code:
* Thrust ratio F_total/F_cruise [-]
* S_wet/S_rev ratio [-]: Ratio of wetted surface to wing reference area to estimate parasetic drag coefficient
* Mass ratio m_cruise/MTOM [-] 


The *Landing* constraint makes sure to respect the maximum approach speed TLAR.
For the determination the following parameters are necessary:

initialSizing_conf:
* CL_max_Landing [-]
* Mass ratio m_land/MTOM [-]: 
acXML:
* v_appr [m/s]: Approch speed TLAR

These constraints open up the design or sizing window of the aircraft where it can fulfill the TLARs and certification standards.

## Initial Constraint Analysis - Desing Point  
The constraints from the section before open up the design or sizing window, where the aircraft can fulfill the TLARs and certification standards.
Selecting the optimal design point within the window is again dependent on various requirements and the constellation of the design window itself. 
This would be quite complex to implement in the module. In order to keep the module and the methods simple, only the borders of the desing window are investigated - since in many cases they deliver an optimal design point. 
In general, a design point with a wing loading as high as possible and a thrust to weight ratio as low as possible is a good choice.  

**Methods**

* This investigation is done by calculating the intersections of the borders.
* It is checked how many intersection points of constraints the borders of the desing window has.
* It is checked if the CL_optimal is within the design window. CL_optimal is a user input in the initialSizing_conf.xml and describes the desing Lift coefficient at initial cruise speed and altitude. 
* If CL_optimal is in the design window the intersection of CL_optimal and the desing window border is used as design point.
* If CL_optimal is not in the design window and there is only one intersection from borders in the window this intetersection is used as design point.
* If CL_optimal is not in the design window and there are two intersection from borders in the window, an interpolated point between these two is used as design point.