---
title: Workflow
summary: Introduces the UNICADO workflow in RCE
authors:
    - Sebastian Oberschwendtner
    - Jens Vilöhr
date: 2024-12-10
---
After installing UNICADO with the provided installer, the workflow can be run in RCE to calculate a converged aircraft, retrofit an already existing aircraft or perform a mission analysis. RCE is an open-source environment developed by the DLR (Deutsches Zentrum für Luft- und Raumfahrt) to connect and run different tools - in the context of UNICADO the individual modules which represent a distinct step in the aircraft development process. RCE can be downloaded from the [official website](https://rcenvironment.de).

## Run the workflow in RCE
To open the UNICADO workflow, launch RCE and with `File → Open Projects from File System` select the `workingDirectoryRCE` folder located in the installation directory of UNICADO. Typically, this folder is found at `C:\Programs\UNICADOworkflow`. Then the file `UNICADOworkflow.wf` can be opened, which should look like this:
<figure markdown>
  ![UNICADO Workflow](assets/images/screenshots/rce.png){width="800"}
  <figcaption>UNICADO Workflow</figcaption>
</figure>

The workflow can be executed with `Run → Execute Workflow...`, after which the user is asked to name the current run and specify the installation path to the installed python version on the computer. Once defined, the workflow will beginn execution. Due to the various iteration steps involved in the aircraft design process, the execution may take some time to complete.  
During execution, log entries of the different modules can be seen in the Workflow Console in RCE. When finished, the results can be found in `workflowResults` in the installation directory of UNICADO, where they can be viewed and analyzed. 

## Configuration Settings
The workflow in RCE can be executed to perform different tasks, depending on the user set `program_settings/design_case_settings/design_mode` value in the configuration file, which can be found in `workingDirectoryRCE/UNICADOworkflow/unicado_workflow_conf.xml`. The following table gives an overview over the different design modes currently possible to run:

|Design Mode|Description|
|---|---|
|Mode 0: Standard design with no check in subprograms|@todo: add a description here. Please note, that an aircraft exchange file with a fully calculated aircraft as well as additional engine data and geometry data depending on the settings in the modules must be defined inside the `projects` folder in the installation directory of UNICADO.|
|Mode 1: Clean sheet design|Based on requirements and design specifications, an aircraft is sized, converged and analyzed. The requirements and design specifications can be set in the aircraft exchange file, which is located in the `projects` folder in the installation directory of UNICADO. For more information how to adjust the parameters, see [Changing the Design Specifications](./tutorials/changing-design-specifications.md).|
|Mode 2: Retrofit design|If an aircraft is already designed, running the UNICADO workflow in the retrofit mode calculates a new aircraft based on the initial, already existing geometry. @todo: Enhance the description here|
|Mode 3: Mission study analysis without design sizing|If an aircraft is already designed, this mode can be used to analyze the aircraft regarding a study mission. Please note, that an aircraft exchange file with a fully calculated aircraft as well as additional engine data and geometry data must be defined inside the `projects` folder in the installation directory of UNICADO.|
|Mode 4: Design sizing without mission study analysis|Based on requirements and design specifications, an aircraft is sized and converged, but it is not analyzed afterward. See [Changing the Design Specifications](./tutorials/changing-design-specifications.md) on how to change the design parameters.|


To speed up the execution of the workflow, the configuration file also holds further parameters to adjust the iteration speed:

|Parameter|Description|Path in Workflow Configuration File
|---|---|---|
|Convergence Criteria|Max. allowed relative change to the last iteration to achieve convergence|`program_settings/design_case_settings/iteration_settings/convergence_criteria`
|Max. number of Iterations|Max. allowed number of iterations before the workflow is aborted|`program_settings/design_case_settings/iteration_settings/max_number_of_iterations_before_exit`